@@ -1,17 +1,17 @@
 // ---------------------------------------------------------------------
-// $Id: GeneticAlgorithm.cc,v 1.39 2007/03/28 09:47:10 daaugusto Exp $
+// $Id: GeneticAlgorithm.cc 151 2008-06-04 01:35:38Z daaugusto $
 //
 //   GeneticAlgorithm.cc (created on Tue Nov 08 01:08:35 BRT 2005)
 // 
 //   Genetic Algorithm File Fitter (gaffitter)
 //
-//   Copyright (C) 2005-2007 Douglas A. Augusto
+//   Copyright (C) 2005-2008 Douglas A. Augusto
 // 
 // This file is part of gaffitter.
 // 
 // gaffitter is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
-// Free Software Foundation; either version 2 of the License, or (at
+// Free Software Foundation; either version 3 of the License, or (at
 // your option) any later version.
 // 
 // gaffitter is distributed in the hope that it will be useful, but
@@ -20,14 +20,14 @@
 // General Public License for more details.
 // 
 // You should have received a copy of the GNU General Public License
-// along with gaffitter; if not, write to the Free Software Foundation,
-// Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// along with gaffitter; if not, see <http://www.gnu.org/licenses/>.
 //
 // ---------------------------------------------------------------------
 
 #include "GeneticAlgorithm.hh"
 
 #include <utility>
+#include <algorithm>
 
 // ---------------------------------------------------------------------
 GeneticAlgorithm::GeneticAlgorithm(vector<SizeName>& sn, Params& p): 
